========================================
Apparent versus true planetary positions
========================================

The Swiss ephemeris provides the calculation of apparent or true planetary
positions. Traditional astrology works with apparent positions. "Apparent"
means that the position where we see the planet is used, not the one where it
actually is. Because the light's speed is finite, a planet is never seen
exactly where it is. (see above, 2.1.3 "The details of coordinate
transformation", light-time and aberration) Astronomers therefore make a
difference between apparent and true positions. However, this effect is below
1 arc minute.

Most astrological ephemerides provide apparent positions. However, this may be
wrong. The use of apparent positions presupposes that astrological effects can
be derived from one of the four fundamental forces of physics, which is
impossible. Also, many astrologers think that astrological "effects" are a
synchronistic phenomenon (the ones familiar with physics may refer to the Bell
theorem). For such reasons, it might be more convincing to work with true
positions.

Moreover, the Swiss Ephemeris supports so-called astrometric positions, which
are used by astronomers when they measure positions of celestial bodies with
respect to fixed stars. These calculations are of no use for astrology, though.

..
